@@ -21,15 +21,23 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """
 
+import ipaddress
+import socket
 import threading
 
 from socketserver import TCPServer
 
+from robot.api import logger
+
 from HttpCtrl.http_handler import HttpHandler
 from HttpCtrl.internal_messages import TerminationRequest
 from HttpCtrl.response_storage import ResponseStorage
 
 
+class TCPServerIPv6(TCPServer):
+    address_family = socket.AF_INET6
+
+
 class HttpServer:
     def __init__(self, host, port):
         self.__host = host
@@ -51,7 +59,7 @@ class HttpServer:
         TCPServer.allow_reuse_address = True
 
         self.__handler = HttpHandler
-        self.__server = TCPServer((self.__host, self.__port), self.__handler)
+        self.__server = self.__create_tcp_server()
 
         try:
             with self.__cv_run:
@@ -81,3 +89,32 @@ class HttpServer:
 
             with self.__cv_run:
                 self.__is_run_state = False
+
+
+    def __create_tcp_server(self):
+        tcp_server = self.__create_ipv6_tcp_server()
+        if tcp_server is not None:
+            return tcp_server
+
+        return self.__create_ipv4_tcp_server()
+
+
+    def __create_ipv6_tcp_server(self):
+        try:
+            ipaddress.IPv6Address(self.__host)  # if throws exception then address is not IPv6
+
+            tcp_server = TCPServerIPv6((self.__host, self.__port), self.__handler)
+
+            logger.info("IPv6 TCP server '%s:%s' is created for HTTP." % (self.__host, str(self.__port)))
+
+            return tcp_server
+        except:
+            return None
+
+
+    def __create_ipv4_tcp_server(self):
+        tcp_server = TCPServer((self.__host, self.__port), self.__handler)
+
+        logger.info("IPv4 TCP server '%s:%s' is created for HTTP." % (self.__host, str(self.__port)))
+
+        return tcp_server
